Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1311)

Unified Diff: content/browser/media/capture/video_capture_oracle.h

Issue 1183553002: Adjust VideoCaptureOracle wrt. out of order captures. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/media/capture/video_capture_oracle.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/media/capture/video_capture_oracle.h
diff --git a/content/browser/media/capture/video_capture_oracle.h b/content/browser/media/capture/video_capture_oracle.h
index 5bb1dd0083a309bb905ca47a8ce0a1329044adc1..db8ae41f65118bdc43bf5a5ae4cb08baef853fb6 100644
--- a/content/browser/media/capture/video_capture_oracle.h
+++ b/content/browser/media/capture/video_capture_oracle.h
@@ -85,8 +85,11 @@ class CONTENT_EXPORT VideoCaptureOracle {
// returned false.
base::TimeDelta duration_of_next_frame_;
- // Stores the frame number from the last delivered frame.
- int last_delivered_frame_number_;
+ // Stores the frame number from the last successfully delivered frame.
+ int last_successfully_delivered_frame_number_;
+
+ // Stores the number of pending frame captures.
+ int num_frames_pending_;
// These track present/paint history and propose whether to sample each event
// for capture. |smoothing_sampler_| uses a "works for all" heuristic, while
« no previous file with comments | « no previous file | content/browser/media/capture/video_capture_oracle.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698